# Plotting

```{eval-rst}
.. module:: drvi.utils.plotting
.. currentmodule:: drvi.utils

.. autosummary::
    :nosignatures:
    :toctree: generated

    plotting.plot_latent_dimension_stats
    plotting.plot_latent_dims_in_umap
    plotting.plot_latent_dims_in_heatmap
    plotting.make_heatmap_groups
    plotting.differential_vars_heatmap
    plotting.show_top_differential_vars
    plotting.show_differential_vars_scatter_plot
    plotting.plot_relevant_genes_on_umap
```
